//
//  Circle.swift
//  Hit
//
//  Created by Mark Meretzky on 11/12/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class Circle: UIView {
	//color is a stored property.
	let color: UIColor;

	//radius is a computed property.
	var radius: CGFloat {
		get {
			return bounds.size.width / 2;
		}
		set(newRadius) {
			bounds = CGRectMake(-newRadius, -newRadius, 2 * newRadius, 2 * newRadius);
		}
	}

	init(color: UIColor) {
		self.color = color;	//self.color is the property, color is the parameter
		super.init(frame: CGRectZero);
		backgroundColor = UIColor.clearColor();
	}

	//Not called by this app, but needed to get it to compile.

	required init(coder aDecoder: NSCoder) {
		color = UIColor.redColor();
		super.init(coder: aDecoder);
	}

	//Return true if the point is on or within the circumference.

	override func pointInside(point: CGPoint, withEvent event: UIEvent?) -> Bool {
		return hypot(point.x, point.y) <= radius;
	}

	//When this circle is touched, bring it in front of the other subviews of
	//the big white View.  (The big white View is the superview of this Circle.)

	override func touchesBegan(touches: NSSet, withEvent event: UIEvent) {
		superview!.bringSubviewToFront(self);
	}

	override func touchesMoved(touches: NSSet, withEvent event: UIEvent) {
		let touch: UITouch = touches.anyObject() as UITouch;
		let location: CGPoint = touch.locationInView(self);
		let previousLocation: CGPoint = touch.previousLocationInView(self);

		//dx and dy are how far to move this Circle.
		let dx: CGFloat = location.x - previousLocation.x;
		let dy: CGFloat = location.y - previousLocation.y;

		center = CGPointMake(center.x + dx, center.y + dy);
	}

	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.

	override func drawRect(var rect: CGRect) {
		// Drawing code
		let c: CGContextRef = UIGraphicsGetCurrentContext();
		CGContextBeginPath(c);
		CGContextAddEllipseInRect(c, bounds);

		//The color property of this Circle is an object.
		//Break it into four numbers.
		var red: CGFloat = 0;
		var green: CGFloat = 0;
		var blue: CGFloat = 0;
		var alpha: CGFloat = 0;
		color.getRed(&red, green: &green, blue: &blue, alpha: &alpha);

		CGContextSetRGBFillColor(c, red, green, blue, alpha);
		CGContextFillPath(c);
	}

}
